{ mailserver, pkgs, config, ... }: 
{
  imports = [
    ./nginx
    mailserver.nixosModule
  ];

  mailserver = rec {
    enable = true;
    domains = [
      "${config.domains.jim1}"
      "${config.domains.jim2}"
      "${config.domains.luna}"
      "${config.domains.corn}"
    ];
    fqdn = "mx.${config.domains.jim1}";
    certificateScheme = "acme-nginx";
    localDnsResolver = false;
    redis.port = 1515;

    dmarcReporting = {
      enable = true;
      domain = "${config.domains.jim1}";
      localpart = "noreply";
      organizationName = "Jimbo's Files";
    };
        
    # A list of accounts, passwords generated with nix-shell -p mkpasswd --run 'mkpasswd -sm bcrypt'
    loginAccounts = {
      "noreply@${config.domains.jim1}" = {
        hashedPasswordFile = config.age.secrets.noreplyMailHash.path;
        sendOnly = true;
      };    
      "jimbo@${config.domains.jim2}" = {
        hashedPasswordFile = config.age.secrets.jimboMailHash.path;
        aliases = [
	  "jimbo@${config.domains.jim1}"
	  "james@${config.domains.jim1}"
	  "james@${config.domains.jim2}"
	  "contact@${config.domains.jim1}"
	  "contact@${config.domains.jim2}"
        ];
      };
      "luna@${config.domains.luna}" = {
        hashedPasswordFile = config.age.secrets.lunaMailHash.path;
      };
      "corn@${config.domains.corn}" = {
        hashedPasswordFile = config.age.secrets.cornMailHash.path;
      };
      "tiny@${config.domains.corn}" = {
        hashedPasswordFile = config.age.secrets.tinyMailHash.path;
      };
    };
  };

  # Assign the correct port
  services.redis.servers.rspamd.port = 1515;
}
